.. -*- mode: rst -*-

=====
Demos
=====

This directory contains a collection of examples or demos (or pointers to
such things) for using Svglib_ in different contexts. Please feel free to
make suggestions if you have something useful to share with others!

Streamlit
---------

Streamlit-Svglib_ is a small Streamlit_ app and is running `live on Streamlit.io`_.
It is expected to include more demos over time. Contributions are welcome!

.. _Svglib: https://github.com/deeplook/svglib
.. _Streamlit-svglib: https://github.com/deeplook/streamlit-svglib
.. _Streamlit: https://streamlit.io
.. _live on Streamlit.io: https://share.streamlit.io/deeplook/streamlit-svglib
